{ :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
  :: QuickReport 3.0 for Delphi 3 or newer                   ::
  ::                                                         ::
  :: Demo to print labels that go from left to right         ::
  ::                                                         ::
  :: Copyright (c) 1999 QuSoft AS                            ::
  :: All Rights Reserved                                     ::
  ::                                                         ::
  :: web: http://www.qusoft.no   fax: +47 22 41 74 91        ::
  ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::: }
unit horLabel;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  quickrpt, Qrctrls, Db, DBTables, ExtCtrls;

type
  THLabel = (h5160, h5161);

  TfrmHorLabels = class(TForm)
    QuickRep1: TQuickRep;
    Table1: TTable;
    Table1CustNo: TFloatField;
    Table1Company: TStringField;
    Table1Addr1: TStringField;
    Table1Addr2: TStringField;
    Table1City: TStringField;
    Table1State: TStringField;
    Table1Zip: TStringField;
    Table1Country: TStringField;
    Table1Phone: TStringField;
    Table1FAX: TStringField;
    Table1TaxRate: TFloatField;
    Table1Contact: TStringField;
    Table1LastInvoiceDate: TDateTimeField;
    QRBand1: TQRBand;
    QRMemo1: TQRMemo;
    QRMemo2: TQRMemo;
    QRMemo3: TQRMemo;
    procedure DetailBand1BeforePrint(Sender: TQRCustomBand;
      var PrintBand: Boolean);
    procedure FormCreate(Sender: TObject);
    procedure QuickRep1BeforePrint(Sender: TCustomQuickRep;
      var PrintReport: Boolean);
  private
    { Private declarations }
    FSkipRow: integer;
    LabelCnt: integer;
    Memos: array[0..2] of TQRMemo;
    procedure AddIfNotBlank(memo: TQRMemo; s: string);
  public
    { Public declarations }
    LabelSize : THLabel;
    SkipRow: integer;
  end;

var
  frmHorLabels: TfrmHorLabels;

implementation

{$R *.DFM}

procedure TfrmHorLabels.FormCreate(Sender: TObject);
begin
  {
    We have an array of TQRMemo and we assign each element to the
    existing memos on the report.  This allows us to set the memo
    properties at design time and it gives us an easy way to reference
    the memos at runtime.
  }

  Memos[0] := qrmemo1;
  Memos[1] := qrmemo2;
  Memos[2] := qrmemo3;
end;

procedure TfrmHorLabels.AddIfNotBlank(memo: TQRMemo; s: string);
begin
  { simple function to only add non blank fields }
  if Trim(s) <> '' then
    memo.Lines.Add(s);
end;

procedure TfrmHorLabels.QuickRep1BeforePrint(Sender: TCustomQuickRep;
  var PrintReport: Boolean);
var
  nIdx: integer;
begin
  FSkipRow := SkipRow;
  if LabelSize = h5160 then begin
    memos[2].Enabled := true;
    LabelCnt := 2;
  end
  else begin
    memos[2].Enabled := FALSE;
    LabelCnt := 1;
  end;

  for nIdx := 0 to LabelCnt do
  begin
    with memos[nIdx] do
    begin
      if Enabled then begin
        // Set the width based on the label size picked
        case LabelSize of
          h5160: Size.Width := 2.60;
          h5161: Size.Width := 4;
        end;

        // Set the location based on the width
        if nIdx > 0 then
          Left := memos[nIdx-1].Left + memos[nIdx-1].Width
        else
          Left := 0;
      end;
    end
  end;
end;

procedure TfrmHorLabels.DetailBand1BeforePrint(Sender: TQRCustomBand;
  var PrintBand: Boolean);
var
  nIdx : integer;
begin
  for nIdx := low(memos) to high(memos) do
    memos[nIdx].Lines.Clear;

  if FSkipRow > 0 then begin
    dec(FSkipRow);
    quickrep1.DataSet.Prior;
  end
  else begin
    with quickrep1.DataSet do
    begin
      for nIdx := 0 to LabelCnt do
      begin
        { Add text to the memo.  We are not using any the data aware
        Quick Report components because we are doing our own dataset
        navigation.}

        { Add the fields to the memo }
        if not EOF then begin
          memos[nIdx].Lines.Add(Table1Company.AsString);

          { simple function to only add non blank fields }
          AddIfNotBlank(memos[nIdx], Table1Addr1.AsString);
          AddIfNotBlank(memos[nIdx], Table1Addr2.AsString);
          AddIfNotBlank(memos[nIdx], Table1City.AsString + ', ' +
            Table1State.AsString + '  ' + Table1Zip.AsString);

        end;
        {
          If we are not on the last label for this band AND we are not at the
          end of the dataset, we find the next record.  We don't do the find
          on the last label as the Report will do this automaticly and if we
          do it, we will skip every 4th record.
        }
        if (nIdx < LabelCnt) and (not EOF) then
          Next
        else
          break;
      end;
    end;
  end;
end;

end.
